pub enum DSUS_A {
DSUS_0 = 0,
DSUS_1 = 1,
}Expand description
Device status suspend.
Value on reset: 0
Variants
DSUS_0 = 0
0: When the device is not connected or not suspended, a writing a 0 has no effect. Writing a 1 never has an effect.
DSUS_1 = 1
1: It is set to 1 when the device has not seen any activity on its upstream port for more than 3 ms. It is reset to 0 on any activity. When the device is suspended (Suspend bit DSUS = 1) and the software writes a 0 to it, the device will generate a remote wake-up. This will only happen when the device is connected (Connect bit = 1).